@@ -1,4 +1,5 @@
-from .ekonf import eKonf, __hydra_version_base__
+from .ekonf import eKonf
+from .base import __hydra_version_base__
 from . import _version
 
 __version__ = _version.get_versions()["version"]
