@@ -229,6 +229,7 @@ def _compose(
 
     :return: The composed config
     """
+    is_initialized = hydra.core.global_hydra.GlobalHydra.instance().is_initialized()
     if config_group:
         _task = config_group.split("=")
         if len(_task) == 2:
@@ -241,44 +242,51 @@ def _compose(
         key = None
         value = None
     if key and value:
+        if is_initialized:
+            cfg = hydra.compose(config_name=config_name, overrides=overrides)
+        else:
+            with hydra.initialize_config_module(
+                config_module="ekorpkit.conf", version_base=__hydra_version_base__
+            ):
+                cfg = hydra.compose(config_name=config_name, overrides=overrides)
+        cfg = _select(
+            cfg,
+            key=key,
+            default=None,
+            throw_on_missing=False,
+            throw_on_resolution_failure=False,
+        )
+        if cfg:
+            overide = config_group
+        else:
+            overide = f"+{config_group}"
+        if overrides:
+            overrides.append(overide)
+        else:
+            overrides = [overide]
+    if verbose:
+        print(f"compose config with overrides: {overrides}")
+    if is_initialized:
+        logging.info("Hydra is already initialized")
+        cfg = hydra.compose(config_name=config_name, overrides=overrides)
+    else:
         with hydra.initialize_config_module(
             config_module="ekorpkit.conf", version_base=__hydra_version_base__
         ):
             cfg = hydra.compose(config_name=config_name, overrides=overrides)
-            cfg = _select(
-                cfg,
-                key=key,
-                default=None,
-                throw_on_missing=False,
-                throw_on_resolution_failure=False,
-            )
-            if cfg:
-                overide = config_group
-            else:
-                overide = f"+{config_group}"
-            if overrides:
-                overrides.append(overide)
-            else:
-                overrides = [overide]
+    if key:
+        cfg = _select(
+            cfg,
+            key=key,
+            default=None,
+            throw_on_missing=throw_on_missing,
+            throw_on_resolution_failure=throw_on_resolution_failure,
+        )
     if verbose:
-        print(f"compose config with overrides: {overrides}")
-    with hydra.initialize_config_module(
-        config_module="ekorpkit.conf", version_base=__hydra_version_base__
-    ):
-        cfg = hydra.compose(config_name=config_name, overrides=overrides)
-        if key:
-            cfg = _select(
-                cfg,
-                key=key,
-                default=None,
-                throw_on_missing=throw_on_missing,
-                throw_on_resolution_failure=throw_on_resolution_failure,
-            )
-        if verbose:
-            print(cfg)
-        if return_as_dict and isinstance(cfg, DictConfig):
-            return _to_dict(cfg)
-        return cfg
+        print(cfg)
+    if return_as_dict and isinstance(cfg, DictConfig):
+        return _to_dict(cfg)
+    return cfg
 
 
 def _to_dict(
@@ -310,7 +318,7 @@ def dotenv_values(dotenv_path=None, **kwargs):
 def getcwd():
     try:
         return hydra.utils.get_original_cwd()
-    except:
+    except Exception:
         return os.getcwd()
 
 
@@ -430,8 +438,14 @@ def _methods(cfg: Any, obj: object, return_function=False):
 
     if isinstance(cfg, dict) and _Keys.METHOD in cfg:
         _method_ = cfg[_Keys.METHOD]
-    else:
+    elif isinstance(cfg, dict):
         _method_ = cfg
+    elif isinstance(cfg, str):
+        _method_ = cfg
+        cfg = {}
+    else:
+        raise ValueError(f"Invalid method: {cfg}")
+
     if isinstance(_method_, str):
         _fn = getattr(obj, _method_)
         if return_function:
@@ -697,15 +711,15 @@ def _load_dotenv(verbose=False):
         logger.info(f"No .env file found in {dotenv_path}")
 
 
-def _osenv(key: str = None) -> Any:
+def _osenv(key: str = None, default: str = None) -> Any:
     _load_dotenv()
     if key:
-        return os.environ.get(key)
+        return os.environ.get(key, default)
     return os.environ
 
 
 def _env_set(key: str, value: Any) -> None:
-    if _is_dir(value):
+    if value and _is_dir(value):
         value = os.path.abspath(value)
     os.environ[key] = value
 
@@ -934,7 +948,7 @@ def _set_cuda(device=0):
         device = ", ".join(ids)
         os.environ["CUDA_DEVICE_ORDER"] = "PCI_BUS_ID"
         os.environ["CUDA_VISIBLE_DEVICES"] = device
-    except:
+    except ImportError:
         os.environ["CUDA_VISIBLE_DEVICES"] = ""
         raise Exception("Cuda device not found")
 
@@ -953,7 +967,8 @@ def _getsource(obj):
             mod = importlib.import_module(mod_name)
             obj = getattr(mod, object_name)
         return inspect.getsource(obj)
-    except:
+    except Exception as e:
+        logger.error(f"Error getting source: {e}")
         return ""
 
 
@@ -964,7 +979,9 @@ def _viewsource(obj):
 
 def _human_readable_type_name(t: Type) -> str:
     """
-    Generates a useful-for-humans label for a type. For builtin types, it's just the class name (eg "str" or "int"). For other types, it includes the module (eg "pathlib.Path").
+    Generates a useful-for-humans label for a type.
+    For builtin types, it's just the class name (eg "str" or "int").
+    For other types, it includes the module (eg "pathlib.Path").
     """
     module = t.__module__
     if module == "builtins":
@@ -1008,3 +1025,19 @@ def _records_to_dataframe(
         coerce_float=coerce_float,
         nrows=nrows,
     )
+
+
+def _set_workspace(
+    workspace=None,
+    project=None,
+):
+    if isinstance(workspace, str):
+        _env_set("EKORPKIT_WORKSPACE_ROOT", workspace)
+        logger.info(f"Setting EKORPKIT_WORKSPACE_ROOT to {workspace}")
+    if isinstance(project, str):
+        _env_set("EKORPKIT_PROJECT", project)
+        logger.info(f"Setting EKORPKIT_PROJECT to {project}")
+    if workspace is not None and project is not None:
+        project_dir = os.path.join(workspace, "projects", project)
+        _env_set("EKORPKIT_PROJECT_DIR", project_dir)
+    return _osenv("EKORPKIT_PROJECT_DIR")
