@@ -4,6 +4,12 @@ from typing import Any, List, IO, Dict, Union, Tuple
 from ekorpkit.utils.notebook import (
     _clear_output,
     _cprint,
+    _create_button,
+    _create_dropdown,
+    _create_floatslider,
+    _create_image,
+    _create_radiobutton,
+    _create_textarea,
     _display,
     _display_image,
     _get_display,
@@ -54,6 +60,7 @@ from .base import (
     _save,
     _select,
     _set_cuda,
+    _set_workspace,
     _setLogger,
     _SPLITS,
     _stop_env_,
@@ -82,6 +89,10 @@ class eKonf:
     __ekorpkit_path__ = __ekorpkit_path__()
     __home_path__ = __home_path__()
     config = _config
+    book_repo = "https://github.com/entelecheia/ekorpkit-book/raw/main/"
+    book_repo_assets = book_repo + "assets/"
+    book_url = "https://entelecheia.github.io/ekorpkit-book/"
+    book_assets_url = book_url + "assets/"
     Keys = _Keys
     Defaults = _Defaults
     SPLITS = _SPLITS
@@ -529,53 +540,37 @@ class eKonf:
 
     @staticmethod
     def collage(
-        image_filepaths=None,
-        filename_patterns=None,
-        base_dir=None,
-        output_filepath=None,
-        ncols=2,
-        num_images=None,
-        figsize=(30, 20),
-        dpi=300,
-        title=None,
-        title_fontsize=12,
+        images_or_uris,
+        collage_filepath=None,
+        ncols=3,
+        max_images=12,
+        collage_width=1200,
+        padding: int = 10,
+        bg_color: str = "black",
+        crop_to_min_size=False,
         show_filename=False,
         filename_offset=(5, 5),
         fontname=None,
         fontsize=12,
-        fontcolor=None,
-        xlabel=None,
-        ylabel=None,
-        xticklabels=None,
-        yticklabels=None,
-        xlabel_fontsize=12,
-        ylabel_fontsize=12,
+        fontcolor="#000",
         **kwargs,
     ):
         from ekorpkit.visualize.collage import collage as _collage
 
         return _collage(
-            image_filepaths=image_filepaths,
-            filename_patterns=filename_patterns,
-            base_dir=base_dir,
-            output_filepath=output_filepath,
+            images_or_uris,
+            collage_filepath=collage_filepath,
             ncols=ncols,
-            num_images=num_images,
-            figsize=figsize,
-            dpi=dpi,
-            title=title,
-            title_fontsize=title_fontsize,
+            max_images=max_images,
+            collage_width=collage_width,
+            padding=padding,
+            bg_color=bg_color,
+            crop_to_min_size=crop_to_min_size,
             show_filename=show_filename,
             filename_offset=filename_offset,
             fontname=fontname,
             fontsize=fontsize,
             fontcolor=fontcolor,
-            xlabel=xlabel,
-            ylabel=ylabel,
-            xticklabels=xticklabels,
-            yticklabels=yticklabels,
-            xlabel_fontsize=xlabel_fontsize,
-            ylabel_fontsize=ylabel_fontsize,
             **kwargs,
         )
 
@@ -667,8 +662,6 @@ class eKonf:
         metadata=None,
         transient=None,
         display_id=None,
-        raw=False,
-        clear=False,
         **kwargs,
     ):
         return _display(
@@ -678,8 +671,6 @@ class eKonf:
             metadata=metadata,
             transient=transient,
             display_id=display_id,
-            raw=raw,
-            clear=clear,
             **kwargs,
         )
 
@@ -777,3 +768,175 @@ class eKonf:
         data, index=None, exclude=None, columns=None, coerce_float=False, nrows=None
     ):
         return _records_to_dataframe(data, index, exclude, columns, coerce_float, nrows)
+
+    @staticmethod
+    def create_dropdown(
+        options,
+        value,
+        description,
+        disabled=False,
+        style={"description_width": "initial"},
+        layout=None,
+        **kwargs,
+    ):
+        return _create_dropdown(
+            options,
+            value,
+            description,
+            disabled,
+            style,
+            layout,
+            **kwargs,
+        )
+
+    @staticmethod
+    def create_textarea(
+        value,
+        description,
+        placeholder="",
+        disabled=False,
+        style={"description_width": "initial"},
+        layout=None,
+        **kwargs,
+    ):
+        return _create_textarea(
+            value,
+            description,
+            placeholder,
+            disabled,
+            style,
+            layout,
+            **kwargs,
+        )
+
+    @staticmethod
+    def create_button(
+        description, button_style="", icon="check", layout=None, **kwargs
+    ):
+        return _create_button(description, button_style, icon, layout, **kwargs)
+
+    @staticmethod
+    def create_radiobutton(
+        options,
+        description,
+        value=None,
+        disabled=False,
+        style={"description_width": "initial"},
+        layout=None,
+        **kwargs,
+    ):
+        return _create_radiobutton(
+            options,
+            description,
+            value,
+            disabled,
+            style,
+            layout,
+            **kwargs,
+        )
+
+    @staticmethod
+    def create_image(
+        filename=None,
+        format=None,
+        width=None,
+        height=None,
+        **kwargs,
+    ):
+        return _create_image(filename, format, width, height, **kwargs)
+
+    @staticmethod
+    def create_floatslider(
+        min=0.0,
+        max=1.0,
+        step=0.1,
+        value=None,
+        description="",
+        disabled=False,
+        continuous_update=False,
+        orientation="horizontal",
+        readout=True,
+        readout_format=".1f",
+        style={"description_width": "initial"},
+        layout=None,
+        **kwargs,
+    ):
+        return _create_floatslider(
+            min,
+            max,
+            step,
+            value,
+            description,
+            disabled,
+            continuous_update,
+            orientation,
+            readout,
+            readout_format,
+            style,
+            layout,
+            **kwargs,
+        )
+
+    @staticmethod
+    def get_image_font(fontname=None, fontsize=12):
+        from ekorpkit.visualize.collage import get_image_font
+
+        return get_image_font(fontname, fontsize)
+
+    @staticmethod
+    def read(uri, mode="rb", encoding=None, head=None, **kwargs):
+        from ekorpkit.io.file import read as _read
+
+        return _read(uri, mode, encoding, head, **kwargs)
+
+    @staticmethod
+    def load_image(
+        image_or_uri,
+        max_width: int = None,
+        max_height: int = None,
+        max_pixels: int = None,
+        scale: float = 1.0,
+        resize_to_multiple_of: int = None,
+        crop_box=None,
+        mode="RGB",
+        **kwargs,
+    ):
+        from ekorpkit.visualize.utils import load_image as _load_image
+
+        return _load_image(
+            image_or_uri,
+            max_width,
+            max_height,
+            max_pixels,
+            scale,
+            resize_to_multiple_of,
+            crop_box,
+            mode,
+            **kwargs,
+        )
+
+    @staticmethod
+    def set_workspace(workspace=None, project=None):
+        return _set_workspace(workspace, project)
+
+    @staticmethod
+    def scale_image(
+        image,
+        max_width: int = None,
+        max_height: int = None,
+        max_pixels: int = None,
+        scale: float = 1.0,
+        resize_to_multiple_of: int = 8,
+        resample: int = None,
+    ):
+        from ekorpkit.visualize.utils import scale_image as _scale_image
+
+        return _scale_image(
+            image,
+            max_width,
+            max_height,
+            max_pixels,
+            scale,
+            resize_to_multiple_of,
+            resample,
+        )
