@@ -85,7 +85,7 @@ def split_prompts(prompts, max_frames):
     prompt_series = pd.Series([np.nan for a in range(max_frames)])
     for i, prompt in prompts.items():
         if isinstance(prompt, str):
-            prompt =[prompt]
+            prompt = [prompt]
         prompt_series[i] = prompt
     # prompt_series = prompt_series.astype(str)
     prompt_series = prompt_series.ffill().bfill()
@@ -119,7 +119,10 @@ def parse_key_frames(string, prompt_parser=None):
     >>> parse_key_frames("10:(Apple: 1| Orange: 0), 20: (Apple: 0| Orange: 1| Peach: 1)")
     {10: 'Apple: 1| Orange: 0', 20: 'Apple: 0| Orange: 1| Peach: 1'}
 
-    >>> parse_key_frames("10:(Apple: 1| Orange: 0), 20: (Apple: 0| Orange: 1| Peach: 1)", prompt_parser=lambda x: x.lower()))
+    >>> parse_key_frames(
+            "10:(Apple: 1| Orange: 0), 20: (Apple: 0| Orange: 1| Peach: 1)",
+            prompt_parser=lambda x: x.lower())
+        )
     {10: 'apple: 1| orange: 0', 20: 'apple: 0| orange: 1| peach: 1'}
     """
     import re
