@@ -5,7 +5,7 @@ import scipy.sparse as ssp
 import random
 import pandas as pd
 from math import ceil
-from tqdm import tqdm
+from tqdm.auto import tqdm
 import contextlib
 
 batcher_instance = None
@@ -67,6 +67,8 @@ class Batcher(object):
         task_num_gpus=0,
         verbose=0,
     ):
+        if isinstance(procs, str):
+            procs = int(procs)
         if procs == 0 or procs is None:
             procs = multiprocessing.cpu_count()
         self.procs = procs
